summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvlookandfeel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvlookandfeel.cpp')
-rw-r--r--ksysv/ksvlookandfeel.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/ksvlookandfeel.cpp b/ksysv/ksvlookandfeel.cpp
index c63c49d..9c68cfb 100644
--- a/ksysv/ksvlookandfeel.cpp
+++ b/ksysv/ksvlookandfeel.cpp
@@ -32,11 +32,11 @@
#include <kfontdialog.h>
/*
* Constructs a KSVLookAndFeel which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVLookAndFeel::KSVLookAndFeel( TQWidget* tqparent, const char* name, WFlags fl )
- : LookAndFeel( tqparent, name, fl )
+KSVLookAndFeel::KSVLookAndFeel( TQWidget* parent, const char* name, WFlags fl )
+ : LookAndFeel( parent, name, fl )
{
mTopLayout->setSpacing (KDialog::spacingHint());
mColorGrid->setSpacing (KDialog::spacingHint());
@@ -32,11 +32,11 @@
#include <kfontdialog.h>
/*
- * Constructs a KSVLookAndFeel which is a child of 'tqparent', with the
+ * Constructs a KSVLookAndFeel which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/